use crate::error_template::{AppError, ErrorTemplate};

use leptos::prelude::*;
use leptos_meta::*;
use leptos_router::{components::*, StaticSegment};

pub mod error_template;

#[cfg(feature = "ssr")]
pub mod state;

mod message;

pub fn shell(options: LeptosOptions) -> impl IntoView {
    view! {
        <!DOCTYPE html>
        <html lang="en">
            <head>
                <meta charset="utf-8" />
                <meta name="viewport" content="width=device-width, initial-scale=1" />
                <AutoReload options=options.clone() />
                <HydrationScripts options />
                <MetaTags />
            </head>
            <body>
                <App />
            </body>
        </html>
    }
}

#[component]
pub fn App() -> impl IntoView {
    // Provides context that manages stylesheets, titles, meta tags, etc.
    provide_meta_context();

    view! {
        <Stylesheet id="leptos" href="/pkg/lebusiness-client.css" />

        // sets the document title
        <Title text="client" />

        // content for this welcome page
        <Router>
            <main class="">
                <Routes fallback=|| {
                    let mut outside_errors = Errors::default();
                    outside_errors.insert_with_default_key(AppError::NotFound);
                    view! { <ErrorTemplate outside_errors /> }.into_view()
                }>
                    <Route path=StaticSegment("") view=HomePage />
                </Routes>
            </main>
        </Router>
    }
}

#[component]
pub fn HomePage() -> impl IntoView {
    let messages = message::get_messages();

    view! {
        <div class="flex flex-col h-screen bg-gray-50">
            <header class="flex items-center py-4 px-4 bg-white border-b border-gray-200">
                <div class="flex justify-between items-center mx-auto w-full max-w-5xl">
                    <h1 class="text-xl font-semibold text-gray-800">Medical Assistant</h1>
                    <button class="flex gap-2 items-center py-2 px-4 text-sm text-gray-600 bg-white rounded-sm border border-gray-200 hover:bg-gray-50">
                        New Chat
                    </button>
                </div>
            </header>

            <div class="overflow-y-auto flex-1 px-4">
                <div class="py-6 mx-auto space-y-6 max-w-5xl">
                    {messages
                        .iter()
                        .map(|message| {
                            view! {
                                <div class=format!(
                                    "flex {}",
                                    if message.role == "assistant" {
                                        "justify-start"
                                    } else {
                                        "justify-end"
                                    },
                                )>
                                    <div class=format!(
                                        "max-w-[80%] rounded-sm px-4 py-3 {}",
                                        if message.role == "assistant" {
                                            "bg-white border border-gray-200"
                                        } else {
                                            "bg-blue-500 text-white"
                                        },
                                    )>{message.content.clone()}</div>
                                </div>
                            }
                        })
                        .collect_view()}
                    <div class="flex justify-start">
                        <div class="py-3 px-4 bg-white rounded-sm border border-gray-200 max-w-[80%]">
                            "Loading..."
                        </div>
                    </div> <div />
                </div>
            </div>

            <div class="py-4 px-4 bg-white border-t border-gray-200">
                <form class="mx-auto max-w-5xl">
                    <div class="flex gap-4">
                        <input
                            type="text"
                            placeholder="Type your medical question here..."
                            class="flex-1 py-2 px-4 rounded-sm border border-gray-200 focus:border-transparent focus:ring-2 focus:ring-blue-500 focus:outline-none"
                        />
                        <button
                            type="submit"
                            class="flex gap-2 items-center py-2 px-4 text-white bg-blue-500 rounded-sm hover:bg-blue-600 disabled:opacity-50 disabled:cursor-not-allowed"
                        >
                            Send
                        </button>
                    </div>
                </form>
            </div>
        </div>
    }
}
